@@ -24,8 +24,9 @@ def generate_shares(f):
 @cli.command()
 @click.argument('f', type=click.File())
 @click.option('--single-account', default=None)
-def deploy(f, single_account):
-    cli_commands.deploy(f, single_account)
+@click.option('--num-workers', default=10)
+def deploy(f, single_account, num_workers):
+    cli_commands.deploy(f, num_workers)
 
 
 @cli.command()
@@ -47,6 +48,14 @@ def bootstrap_spoke(puppet_account_id):
     cli_commands.bootstrap_spoke(puppet_account_id)
 
 
+@cli.command()
+@click.argument('ou_path_or_id')
+@click.argument('role_name')
+@click.argument('iam_role_arns', nargs=-1)
+def bootstrap_spokes_in_ou(ou_path_or_id, role_name, iam_role_arns):
+    cli_commands.bootstrap_spokes_in_ou(ou_path_or_id, role_name, iam_role_arns)
+
+
 @cli.command()
 @click.argument('branch-name')
 @click.option('--with-manual-approvals/--with-no-manual-approvals', default=False)
@@ -170,5 +179,18 @@ def reset_provisioned_product_owner(f):
     cli_commands.reset_provisioned_product_owner(f)
 
 
+@cli.command()
+@click.argument('regions', nargs=-1)
+def set_regions(regions):
+    cli_commands.set_config_value('regions', regions)
+
+
+@cli.command()
+@click.argument('name')
+@click.argument('value')
+def set_config_value(name, value, type=bool):
+    cli_commands.set_config_value(name, value)
+
+
 if __name__ == "__main__":
     cli()
