@@ -33,4 +33,9 @@ CHANGE = 'CHANGE'
 
 EVENT_BUS_NAME = "servicecatalog-puppet-event-bus"
 SERVICE_CATALOG_PUPPET_EVENT_SOURCE = "servicecatalog-puppet"
-SERVICE_CATALOG_PUPPET_OPS_CENTER_SOURCE = "servicecatalog-puppet"
\ No newline at end of file
+SERVICE_CATALOG_PUPPET_OPS_CENTER_SOURCE = "servicecatalog-puppet"
+
+HOME_REGION = os.environ.get('AWS_REGION', os.environ.get('AWS_DEFAULT_REGION', 'eu-west-1'))
+
+
+EVENTBRIDGE_MAX_EVENTS_PER_CALL = 10
\ No newline at end of file
